# Antidote — API JS-Connect v3

L’API JS-Connect d’Antidote permet d’insérer les 3 boutons d’Antidote (Correcteur, Dictionnaires, Guides) dans une page HTML.

Les boutons insérés agissent comme si Antidote était appelé par les boutons du connecteur depuis la barre du fureteur.

De plus, pour le correcteur, l’API permet de lier un ou plusieurs champs éditables au bouton inséré, de sorte que seulement les champs liés un bouton soient traités. Il est également possible d’insérer plusieurs boutons du correcteur, chaque bouton étant lié à un groupe de champs à corriger.

---

## Important

- Voir le fichier [index.html](index.html) pour plus de détails.

- S’assurer que le connecteur d’Antidote soit installé et qu’il offre l’API JS-Connect. 
Pour ce faire:
	- vérifier la présence de l’identifiant antidoteapi_jsconnect_actif. Par exemple:
		```var API_JS-Connect_EstPresent = document.getElementById('antidoteapi_jsconnect_actif') != null;```

- Les boutons insérés ne doivent pas être sélectionnables.

- Les champs éditables peuvent être liés seulement au correcteur (et non aux dictionnaires ou aux guides).

---
## Activation des boutons

L’activation d’un bouton permet de déclencher une action de l’API lorsque le bouton est cliqué.

Au chargement de la page, tous les boutons présents sont automatiquement activés ; pour que cette activation automatique s’effectue, le noeud ```<html>``` doit contenir l’attribut
	```antidoteapi_jsconnect="true"```.

Si un bouton est ajouté après le chargement de la page, il faut l’activer par l’appel suivant (qui active tous les boutons non encore activés):
	```window.activeAntidoteAPI_JSConnect();```

La désactivation des boutons insérés se fait par l’appel suivant:
	```window.desactiveAntidoteAPI_JSConnect();```

Voir [exemple d’activation](index.html#activation)

### Fonction de rappel

Si la page a besoin de déclencher la sauvegarde après un changement, passer la fonction de rappel (callback) en paramètre :
	```window.activeAntidoteAPI_JSConnect(votreFonctionDeRappel);```

- Version minimale des connecteurs
	- Firefox : 11.5.1937
	- Google Chrome : 11.5.1937
	- Safari : 11.5.1937

---
## Boutons non liés

Pour insérer un bouton non lié, ajouter dans le code HTML un noeud ayant l’attribut data-antidoteapi_jsconnect_lanceoutil avec l’un des paramètres suivants:
	"C" pour lancer le Correcteur
	"D" pour lancer les Dictionnaires
	"G" pour lancer les Guides
Par exemple: 
```
<button data-antidoteapi_jsconnect_lanceoutil="C">
```

Voir [exemple 1](index.html#exemple1)

---
## Bouton lié à un champ éditable

Pour insérer un bouton du correcteur et le lier à un champ éditable:

- ajouter l’attribut `data-antidoteapi_jsconnect_groupe_id=PARAM` dans le noeud du champ éditable à lier, où `PARAM` identifie le champ à lier.
Par exemple:
```
	<textarea id="exemple2" data-antidoteapi_jsconnect_groupe_id="mon_groupe_02">
```

- en plus de l’attribut data-antidoteapi_jsconnect_lanceoutil, ajouter l’attribut `data-antidoteapi_jsconnect_groupe_id=PARAM` dans le noeud du bouton.
Par exemple:
```
	<button data-antidoteapi_jsconnect_lanceoutil="C" data-antidoteapi_jsconnect_groupe_id="mon_groupe_02">
```

Voir [exemple 2](index.html#exemple2)

---
## Bouton lié à des champs éditables

Pour insérer un bouton du correcteur et le lier à un groupe de champs éditables:

- ajouter l’attribut `data-antidoteapi_jsconnect_groupe_id=PARAM` dans le noeud de chaque champ éditable à lier, où `PARAM` identifie les champs à lier.
Par exemple:
```
	<textarea id="exemple3_a" data-antidoteapi_jsconnect_groupe_id="mon_groupe_03">
    <textarea id="exemple3_b" data-antidoteapi_jsconnect_groupe_id="mon_groupe_03">
```

- en plus de l’attribut data-antidoteapi_jsconnect_lanceoutil, ajouter l’attribut `data-antidoteapi_jsconnect_groupe_id=PARAM` dans le noeud du bouton.
Par exemple:
```
	<button data-antidoteapi_jsconnect_lanceoutil="C" data-antidoteapi_jsconnect_groupe_id="mon_groupe_03">
```
Note : le traitement de zones mixtes (noeud contenteditable=true + textarea), il faut avoir les connecteurs 11.0.12 et plus.

* Voir [exemple 3 (textarea)](index.html#exemple3)
* Voir [exemple 4 (div)](index.html#exemple4)
* Voir [exemple 5 (div + textarea)](index.html#exemple5)
* Voir [exemple 6 (iframe + textarea)](index.html#exemple6)

---
## Exemple d’implémentation

1. Installer le connecteur d’Antidote dans un fureteur Web (Firefox, Google Chrome, Safari).

2. S’assurer que le connecteur d’Antidote offre l’API JS-Connect (voir ci-dessus).

3. Copier les fichiers suivants dans un même dossier sur un serveur Web:
	* index.html
    * antidote-api-js-connect-iframe.html
	* antidote-api-js-connect.js
	* antidote-api-js-connect.css
	* images/

4. Charger la page index.html dans le fureteur.

____________________________________
Avril 2025, © Druide informatique inc.
